@@ -205,20 +205,35 @@ def test_flow_event():
     - From 1st event000 to 2nd event001
     - From 1st event001 to 2nd event000
     - From 1st event001 to 2nd event001
+    - From 1st event001 to event on process 100
     """
-    event_start = TraceEventFlowStart('flow', 123, 100)
-    event_end = TraceEventFlowEnd('flow', 456, 100)
+    event_start = TraceEventFlowStart('flow', 123, 1, 2, 100)
+    event_end = TraceEventFlowEnd('flow', 456, 3, 4, 100)
     assert event_start.tef['ph'] == 's'
+    assert event_start.tef['pid'] == 1
+    assert event_start.tef['tid'] == 2
     assert event_end.tef['ph'] == 'f'
+    assert event_end.tef['pid'] == 3
+    assert event_end.tef['tid'] == 4
     assert event_start.tef['id'] == 100
     assert event_end.tef['id'] == 100
 
     trace = setup_trace(n_repeat=3)
-    trace.add_flow('flow1', trace.events[1], trace.events[6])
-    trace.add_flow('flow2', trace.events[1], trace.events[7])
-    trace.add_flow('flow3', trace.events[0], trace.events[7])
+    trace.add_flow('flow1', trace.events[0], trace.events[7])
+    trace.add_flow('flow2', trace.events[1], trace.events[6])
+    trace.add_flow('flow3', trace.events[1], trace.events[7])
 
     trace.set_process_name(0, 'test process')
     trace.set_thread_name(0, 0, 'test thread')
 
+    another_duration_start = TraceEventDurationBegin(
+        'event on process 100', 3, pid=100, tid=100
+    )
+    another_duration_end = TraceEventDurationEnd(
+        'event on process 100', 8, pid=100, tid=100
+    )
+    trace.add_event(another_duration_start)
+    trace.add_event(another_duration_end)
+    trace.add_flow('flow4', trace.events[1], another_duration_start)
+
     trace.to_tef_json(open('test.json', 'w'))
